@@ -1,7 +1,7 @@
 // ------------------------------------------------------------------------
 //
 // SPDX-License-Identifier: LGPL-2.1-or-later
-// Copyright (C) 2005 - 2024 by the deal.II authors
+// Copyright (C) 2005 - 2025 by the deal.II authors
 //
 // This file is part of the deal.II library.
 //
@@ -35,47 +35,34 @@ class ReferenceCell;
  */
 
 /**
- * This class is a helper class to facilitate the usage of quadrature formulae
- * on faces or subfaces of cells. It computes the locations of quadrature
- * points on the unit cell from a quadrature object for a manifold of one
- * dimension less than that of the cell and the number of the face. For
- * example, giving the Simpson rule in one dimension and using the
- * project_to_face() function with face number 1, the returned points will be
- * (1,0), (1,0.5) and (1,1). Note that faces have an orientation, so when
- * projecting to face 3, you will get (0,0), (0,0.5) and (0,1), which is in
- * clockwise sense, while for face 1 the points were in counterclockwise
- * sense.
+ * @brief Class which transforms `dim - 1`-dimensional quadrature rules to
+ * `dim`-dimensional face quadratures.
  *
- * For the projection to subfaces (i.e. to the children of a face of the unit
- * cell), the same applies as above. Note the order in which the children of a
- * face are numbered, which in two dimensions coincides with the orientation
- * of the face.
+ * The majority of the finite element infrastructure, such as FE_Q and
+ * FE_SimplexP, uses polynomials defined on a reference cell: for example,
+ * FE_Q<3> defines a polynomial space whose domain is the unit hexahedron (i.e.,
+ * ReferenceCells::Hexahedron). Hence, computing quadratures using shape
+ * functions on a face of a reference cell requires converting a
+ * lower-dimensional Quadrature into one defined on the boundary of the
+ * higher-dimensional object, e.g., converting a Quadrature defined on a
+ * quadrilateral into one defined on one face of a hexahedron.
  *
- * The second set of functions generates a quadrature formula by projecting a
- * given quadrature rule on <b>all</b> faces and subfaces. This is used in the
- * FEFaceValues and FESubfaceValues classes. Since we now have the quadrature
- * points of all faces and subfaces in one array, we need to have a way to
- * find the starting index of the points and weights corresponding to one face
- * or subface within this array. This is done through the DataSetDescriptor
- * member class.
+ * QProjector computes the locations of quadrature points on faces or subfaces
+ * of reference cells from a Quadrature of one dimension less than that of the
+ * cell, face (and possibly also subface) number, and orientation. For example,
+ * calling QProjector::project_to_face() with QSimpson<1>, face number 1, and
+ * numbers::default_geometric_orientation returns a Quadrature with points
+ * (1,0), (1,0.5), and (1,1) with weights equal to the 1d case. Similarly, if we
+ * instead use face 3 and numbers::reverse_line_orientation we obtain points
+ * (1,1), (0.5,1) and (0,1). Projection to subfaces works in the same way.
  *
- * The different functions are grouped into a common class to avoid putting
- * them into global namespace. However, since they have no local data, all
- * functions are declared <tt>static</tt> and can be called without creating
- * an object of this class.
- *
- * For the 3d case, you should note that the orientation of faces is even more
- * intricate than for two dimensions. Quadrature formulae are projected upon
- * the faces in their standard orientation, not to the inside or outside of
- * the hexahedron. To make things more complicated, in 3d we allow faces in
- * two orientations (which can be identified using
- * <tt>cell->face_orientation(face)</tt>), so we have to project quadrature
- * formula onto faces and subfaces in two orientations. (Refer to the
- * documentation of the Triangulation class for a description of the
- * orientation of the different faces, as well as to
- * @ref GlossFaceOrientation "the glossary entry on face orientation"
- * for more information on this.) The DataSetDescriptor member class is used
- * to identify where each dataset starts.
+ * In practice, computing face integrals (e.g., via FEFaceValues or
+ * FESubfaceValues) requires quadrature rules for all possible permutations of
+ * face number, subface number, and combined orientation. This class provides
+ * several functions for doing just that, such as
+ * QProjector::project_to_all_faces(). Furthermore, the DataSetDescriptor class
+ * implements indexing for converting between face number, subface number, and
+ * combined orientation to the index of the associated Quadrature rule.
  */
 template <int dim>
 class QProjector
@@ -91,7 +78,13 @@ public:
    * Compute the quadrature points on the cell if the given quadrature formula
    * is used on face <tt>face_no</tt>. For further details, see the general
    * doc for this class.
+   *
+   * @deprecated Use the version of this function which takes a
+   * combined_orientation argument instead.
    */
+  DEAL_II_DEPRECATED_EARLY_WITH_COMMENT(
+    "Use the version of this function which takes a combined_orientation "
+    "argument instead.")
   static void
   project_to_face(const ReferenceCell     &reference_cell,
                   const SubQuadrature     &quadrature,
@@ -102,7 +95,13 @@ public:
    * Compute the cell quadrature formula corresponding to using
    * <tt>quadrature</tt> on face <tt>face_no</tt>. For further details, see
    * the general doc for this class.
+   *
+   * @deprecated Use the version of this function which takes a
+   * combined_orientation argument instead.
    */
+  DEAL_II_DEPRECATED_EARLY_WITH_COMMENT(
+    "Use the version of this function which takes a combined_orientation "
+    "argument instead.")
   static Quadrature<dim>
   project_to_face(const ReferenceCell &reference_cell,
                   const SubQuadrature &quadrature,
@@ -113,7 +112,13 @@ public:
    * <tt>quadrature</tt> on face <tt>face_no</tt> taking into account the
    * orientation of the face. For further details, see the general doc for this
    * class.
+   *
+   * @deprecated Use the version of project_to_face() which takes a
+   * combined_orientation argument instead.
    */
+  DEAL_II_DEPRECATED_EARLY_WITH_COMMENT(
+    "Use the version of project_to_face() which takes a combined_orientation "
+    "argument instead.")
   static Quadrature<dim>
   project_to_oriented_face(const ReferenceCell &reference_cell,
                            const SubQuadrature &quadrature,
@@ -122,6 +127,17 @@ public:
                            const bool           face_flip,
                            const bool           face_rotation);
 
+  /**
+   * Compute the cell quadrature formula corresponding to using
+   * <tt>quadrature</tt> on face <tt>face_no</tt>. For further details, see
+   * the general doc for this class.
+   */
+  static Quadrature<dim>
+  project_to_face(const ReferenceCell               &reference_cell,
+                  const SubQuadrature               &quadrature,
+                  const unsigned int                 face_no,
+                  const types::geometric_orientation combined_orientation);
+
   /**
    * Compute the quadrature points on the cell if the given quadrature formula
    * is used on face <tt>face_no</tt>, subface number <tt>subface_no</tt>
@@ -130,7 +146,13 @@ public:
    *
    * @note Only the points are transformed. The quadrature weights are the
    * same as those of the original rule.
+   *
+   * @deprecated Use the version of project_to_subface() which takes a
+   * combined_orientation argument instead.
    */
+  DEAL_II_DEPRECATED_EARLY_WITH_COMMENT(
+    "Use the version of project_to_subface() which takes a "
+    "combined_orientation argument instead.")
   static void
   project_to_subface(const ReferenceCell           &reference_cell,
                      const SubQuadrature           &quadrature,
@@ -152,7 +174,13 @@ public:
    * @note This function is deprecated since it makes an implicit assumption
    * that the cell is a line (1D), a quad (2d), or a hex (3d). Use the other
    * version of this function that takes the reference cell type instead.
+   *
+   * @deprecated Use the version of project_to_subface() which takes a
+   * combined_orientation argument instead.
    */
+  DEAL_II_DEPRECATED_EARLY_WITH_COMMENT(
+    "Use the version of project_to_subface() which takes a "
+    "combined_orientation argument instead.")
   static Quadrature<dim>
   project_to_subface(const ReferenceCell           &reference_cell,
                      const SubQuadrature           &quadrature,
@@ -169,7 +197,13 @@ public:
    *
    * @note Only the points are transformed. The quadrature weights are the
    * same as those of the original rule.
+   *
+   * @deprecated Use the version of project_to_subface() which takes a
+   * combined_orientation argument instead.
    */
+  DEAL_II_DEPRECATED_EARLY_WITH_COMMENT(
+    "Use the version of project_to_subface() which takes a "
+    "combined_orientation argument instead.")
   static Quadrature<dim>
   project_to_oriented_subface(const ReferenceCell             &reference_cell,
                               const SubQuadrature             &quadrature,
@@ -180,6 +214,23 @@ public:
                               const bool                       face_rotation,
                               const internal::SubfaceCase<dim> ref_case);
 
+  /**
+   * Compute the cell quadrature formula corresponding to using
+   * <tt>quadrature</tt> on subface <tt>subface_no</tt> of face
+   * <tt>face_no</tt> with RefinementCase<dim-1> <tt>ref_case</tt>. The last
+   * argument is only used in 3d.
+   *
+   * @note Only the points are transformed. The quadrature weights are the
+   * same as those of the original rule.
+   */
+  static Quadrature<dim>
+  project_to_subface(const ReferenceCell               &reference_cell,
+                     const SubQuadrature               &quadrature,
+                     const unsigned int                 face_no,
+                     const unsigned int                 subface_no,
+                     const types::geometric_orientation combined_orientation,
+                     const RefinementCase<dim - 1>     &ref_case);
+
   /**
    * Take a collection of face quadrature formulas and generate a cell
    * quadrature formula from it where the quadrature points of the given
@@ -193,8 +244,9 @@ public:
    * to a single face and use it as a quadrature on this face, as is done in
    * FEFaceValues.
    *
-   * @note In 3d, this function produces eight sets of quadrature points for
-   * each face, in order to cope possibly different orientations of the mesh.
+   * @note This function creates ReferenceCell::n_face_orientations() sets of
+   * quadrature points for each face which are indexed (by combined orientation
+   * and face number) by a DataSetDescriptor.
    */
   static Quadrature<dim>
   project_to_all_faces(const ReferenceCell            &reference_cell,
@@ -234,6 +286,8 @@ public:
    * As integration using this quadrature formula now only extends over a
    * fraction of the cell, the weights of the resulting object are divided by
    * GeometryInfo<dim>::children_per_cell.
+   *
+   * @warning This function is only implemented for hypercube elements.
    */
   static Quadrature<dim>
   project_to_child(const ReferenceCell   &reference_cell,
@@ -248,6 +302,8 @@ public:
    *
    * The child numbering is the same as the children would be numbered upon
    * refinement of the cell.
+   *
+   * @warning This function is only implemented for hypercube elements.
    */
   static Quadrature<dim>
   project_to_all_children(const ReferenceCell   &reference_cell,
@@ -264,14 +320,15 @@ public:
                   const Point<dim>    &p2);
 
   /**
-   * Since the project_to_all_faces() and project_to_all_subfaces() functions
-   * chain together the quadrature points and weights of all projections of a
-   * face quadrature formula to the faces or subfaces of a cell, we need a way
-   * to identify where the starting index of the points and weights for a
-   * particular face or subface is. This class provides this: there are static
-   * member functions that generate objects of this type, given face or
-   * subface indices, and you can then use the generated object in place of an
-   * integer that denotes the offset of a given dataset.
+   * @brief Class storing the offset index into a Quadrature rule created by
+   * project_to_all_faces() or project_to_all_subfaces().
+   *
+   * The functions QProjector::project_to_all_faces() and
+   * QProjector::project_to_all_subfaces() each combine all quadrature rules
+   * (i.e., all possible combinations of face, subface, and combined
+   * orientation) into a single Quadrature object. DataSetDescriptor implements
+   * the correct indexing for extracting from that Quadrature rule the correct
+   * index for those values.
    */
   class DataSetDescriptor
   {
@@ -305,7 +362,7 @@ public:
      * @deprecated Use the version of this function which takes a
      * combined_orientation argument instead.
      */
-    DEAL_II_DEPRECATED_EARLY_WITH_COMMENT(
+    DEAL_II_DEPRECATED_WITH_COMMENT(
       "Use the version of this function which takes a combined_orientation "
       "argument instead.")
     static DataSetDescriptor
@@ -318,19 +375,17 @@ public:
 
     /**
      * Static function to generate an offset object for a given face of a cell
-     * with the given combined face orientation. This function of course is only
-     * allowed if <tt>dim>=2</tt>, and @p combined_orientation is ignored if the
-     * space dimension equals 2.
+     * with the given combined face orientation.
      *
      * @p n_quadrature_points is the number of quadrature points the
      * lower-dimensional face quadrature formula (the one that has been
      * projected onto the faces) has.
      */
     static DataSetDescriptor
-    face(const ReferenceCell &reference_cell,
-         const unsigned int   face_no,
-         const unsigned char  combined_orientation,
-         const unsigned int   n_quadrature_points);
+    face(const ReferenceCell               &reference_cell,
+         const unsigned int                 face_no,
+         const types::geometric_orientation combined_orientation,
+         const unsigned int                 n_quadrature_points);
 
     /**
      * Compute an offset object for the given face number and orientation,
@@ -340,7 +395,7 @@ public:
      * @deprecated Use the version of this function which takes a
      * combined_orientation argument instead.
      */
-    DEAL_II_DEPRECATED_EARLY_WITH_COMMENT(
+    DEAL_II_DEPRECATED_WITH_COMMENT(
       "Use the version of this function which takes a combined_orientation "
       "argument instead.")
     static DataSetDescriptor
@@ -358,10 +413,10 @@ public:
      *
      */
     static DataSetDescriptor
-    face(const ReferenceCell            &reference_cell,
-         const unsigned int              face_no,
-         const unsigned char             combined_orientation,
-         const hp::QCollection<dim - 1> &quadrature);
+    face(const ReferenceCell               &reference_cell,
+         const unsigned int                 face_no,
+         const types::geometric_orientation combined_orientation,
+         const hp::QCollection<dim - 1>    &quadrature);
 
     /**
      * Static function to generate an offset object for a given subface of a
@@ -378,7 +433,7 @@ public:
      * @deprecated Use the version of this function which takes a
      * combined_orientation argument instead.
      */
-    DEAL_II_DEPRECATED_EARLY_WITH_COMMENT(
+    DEAL_II_DEPRECATED_WITH_COMMENT(
       "Use the version of this function which takes a combined_orientation "
       "argument instead.")
     static DataSetDescriptor
@@ -405,12 +460,12 @@ public:
      * Through the last argument anisotropic refinement can be respected.
      */
     static DataSetDescriptor
-    subface(const ReferenceCell             &reference_cell,
-            const unsigned int               face_no,
-            const unsigned int               subface_no,
-            const unsigned char              combined_orientation,
-            const unsigned int               n_quadrature_points,
-            const internal::SubfaceCase<dim> ref_case =
+    subface(const ReferenceCell               &reference_cell,
+            const unsigned int                 face_no,
+            const unsigned int                 subface_no,
+            const types::geometric_orientation combined_orientation,
+            const unsigned int                 n_quadrature_points,
+            const internal::SubfaceCase<dim>   ref_case =
               internal::SubfaceCase<dim>::case_isotropic);
 
     /**
@@ -507,12 +562,6 @@ QProjector<3>::project_to_face(const ReferenceCell   &reference_cell,
                                const unsigned int     face_no,
                                std::vector<Point<3>> &q_points);
 
-template <>
-Quadrature<1>
-QProjector<1>::project_to_all_faces(const ReferenceCell      &reference_cell,
-                                    const hp::QCollection<0> &quadrature);
-
-
 template <>
 void
 QProjector<1>::project_to_subface(const ReferenceCell &reference_cell,
