@@ -1,7 +1,7 @@
 // ------------------------------------------------------------------------
 //
 // SPDX-License-Identifier: LGPL-2.1-or-later
-// Copyright (C) 2015 - 2024 by the deal.II authors
+// Copyright (C) 2015 - 2025 by the deal.II authors
 //
 // This file is part of the deal.II library.
 //
@@ -34,11 +34,9 @@
 #  include <deal.II/lac/trilinos_epetra_communication_pattern.h>
 #  include <deal.II/lac/trilinos_vector.h>
 
+DEAL_II_DISABLE_EXTRA_DIAGNOSTICS
 #  include <Epetra_Import.h>
-#endif
-
-#ifdef DEAL_II_WITH_CUDA
-#  include <deal.II/lac/cuda_vector.h>
+DEAL_II_ENABLE_EXTRA_DIAGNOSTICS
 #endif
 
 #include <boost/io/ios_state.hpp>
@@ -96,16 +94,11 @@ namespace LinearAlgebra
       static void
       import_elements(
         const std::shared_ptr<const ::dealii::Utilities::MPI::Partitioner>
-                                                         &communication_pattern,
-        const Number                                     *values,
-        const VectorOperation::values                     operation,
-        ::dealii::LinearAlgebra::ReadWriteVector<Number> &rw_vector)
+          & /*communication_pattern*/,
+        const Number * /*values*/,
+        const VectorOperation::values /*operation*/,
+        ::dealii::LinearAlgebra::ReadWriteVector<Number> & /*rw_vector*/)
       {
-        (void)communication_pattern;
-        (void)values;
-        (void)operation;
-        (void)rw_vector;
-
         static_assert(
           std::is_same_v<MemorySpace, ::dealii::MemorySpace::Host> ||
             std::is_same_v<MemorySpace, ::dealii::MemorySpace::Default>,
@@ -346,7 +339,6 @@ namespace LinearAlgebra
   {
     Assert(s == static_cast<Number>(0),
            ExcMessage("Only 0 can be assigned to a vector."));
-    (void)s;
 
     const size_type this_size = locally_owned_size();
     if (this_size > 0)
@@ -400,10 +392,8 @@ namespace LinearAlgebra
     const dealii::Vector<Number> &vec,
     VectorOperation::values       operation,
     const std::shared_ptr<const Utilities::MPI::CommunicationPatternBase>
-      &communication_pattern)
+      & /*communication_pattern*/)
   {
-    (void)communication_pattern;
-
     internal::import_serial_vector(vec, operation, *this);
   }
 
@@ -560,7 +550,7 @@ namespace LinearAlgebra
           communication_pattern);
         AssertThrow(tpetra_comm_pattern != nullptr,
                     ExcMessage(
-                      std::string("The communication pattern is not of type ") +
+                      "The communication pattern is not of type "
                       "LinearAlgebra::TpetraWrappers::CommunicationPattern."));
       }
 
@@ -690,7 +680,7 @@ namespace LinearAlgebra
             communication_pattern);
         AssertThrow(epetra_comm_pattern != nullptr,
                     ExcMessage(
-                      std::string("The communication pattern is not of type ") +
+                      "The communication pattern is not of type "
                       "LinearAlgebra::EpetraWrappers::CommunicationPattern."));
       }
 
@@ -853,96 +843,6 @@ namespace LinearAlgebra
 
 
 
-#ifdef DEAL_II_WITH_CUDA
-  template <typename Number>
-  void
-  ReadWriteVector<Number>::import_elements(
-    const LinearAlgebra::CUDAWrappers::Vector<Number> &cuda_vec,
-    VectorOperation::values                            operation,
-    const std::shared_ptr<const Utilities::MPI::CommunicationPatternBase> &)
-  {
-    const unsigned int n_elements = stored_elements.n_elements();
-    if (operation == VectorOperation::insert)
-      {
-        cudaError_t error_code = cudaMemcpy(values.data(),
-                                            cuda_vec.get_values(),
-                                            n_elements * sizeof(Number),
-                                            cudaMemcpyDeviceToHost);
-        AssertCuda(error_code);
-      }
-    else if (operation == VectorOperation::add)
-      {
-        // Copy the vector from the device to a temporary vector on the host
-        std::vector<Number> tmp(n_elements);
-        cudaError_t         error_code = cudaMemcpy(tmp.data(),
-                                            cuda_vec.get_values(),
-                                            n_elements * sizeof(Number),
-                                            cudaMemcpyDeviceToHost);
-        AssertCuda(error_code);
-
-        // Add the two vectors
-        for (unsigned int i = 0; i < n_elements; ++i)
-          values[i] += tmp[i];
-      }
-    else if (operation == VectorOperation::min)
-      {
-        // Copy the vector from the device to a temporary vector on the host
-        std::vector<Number> tmp(n_elements);
-        cudaError_t         error_code = cudaMemcpy(tmp.data(),
-                                            cuda_vec.get_values(),
-                                            n_elements * sizeof(Number),
-                                            cudaMemcpyDeviceToHost);
-        AssertCuda(error_code);
-
-        // To ensure that this code also compiles with complex
-        // numbers, we only compare the real part of the
-        // variable. Note that min/max do not make sense with complex
-        // numbers.
-        for (unsigned int i = 0; i < n_elements; ++i)
-          {
-            Assert(
-              std::imag(tmp[i]) == 0.,
-              ExcMessage(
-                "VectorOperation::min is not defined if there is an imaginary part!)"));
-            Assert(
-              std::imag(values[i]) == 0.,
-              ExcMessage(
-                "VectorOperation::min is not defined if there is an imaginary part!)"));
-            if (std::real(tmp[i]) - std::real(values[i]) < 0.0)
-              values[i] = tmp[i];
-          }
-      }
-    else if (operation == VectorOperation::max)
-      {
-        // Copy the vector from the device to a temporary vector on the host
-        std::vector<Number> tmp(n_elements);
-        cudaError_t         error_code = cudaMemcpy(tmp.data(),
-                                            cuda_vec.get_values(),
-                                            n_elements * sizeof(Number),
-                                            cudaMemcpyDeviceToHost);
-        AssertCuda(error_code);
-
-        for (unsigned int i = 0; i < n_elements; ++i)
-          {
-            Assert(
-              std::imag(tmp[i]) == 0.,
-              ExcMessage(
-                "VectorOperation::max is not defined if there is an imaginary part!)"));
-            Assert(
-              std::imag(values[i]) == 0.,
-              ExcMessage(
-                "VectorOperation::max is not defined if there is an imaginary part!)"));
-            if (std::real(tmp[i]) - std::real(values[i]) > 0.0)
-              values[i] = tmp[i];
-          }
-      }
-    else
-      AssertThrow(false, ExcNotImplemented());
-  }
-#endif
-
-
-
   template <typename Number>
   void
   ReadWriteVector<Number>::swap(ReadWriteVector<Number> &v) noexcept
