@@ -1,7 +1,7 @@
 // ------------------------------------------------------------------------
 //
 // SPDX-License-Identifier: LGPL-2.1-or-later
-// Copyright (C) 1998 - 2020 by the deal.II authors
+// Copyright (C) 1998 - 2025 by the deal.II authors
 //
 // This file is part of the deal.II library.
 //
@@ -19,7 +19,7 @@ DEAL_II_NAMESPACE_OPEN
 namespace Functions
 {
   // explicit instantiations
-#  include "symbolic_function.inst"
+#  include "base/symbolic_function.inst"
 } // namespace Functions
 #endif
 DEAL_II_NAMESPACE_CLOSE
